/**
 * The libroutermanager project
 * Copyright (c) 2012-2014 Jan-Michael Brummer
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef FIRMWARE_04_00_H
#define FIRMWARE_04_00_H

G_BEGIN_DECLS

gboolean fritzbox_present_04_00(struct router_info *router_info);
gboolean fritzbox_login_04_00(struct profile *profile);
gboolean fritzbox_dial_number_04_00(struct profile *profile, gint port, const gchar *number);
gboolean fritzbox_hangup_04_00(struct profile *profile, gint port, const gchar *number);

G_END_DECLS

#endif
